@@ -231,20 +231,36 @@ on_uids_add (GSimpleAction *action, GVariant *param, gpointer user_data)
                                        GTK_WINDOW (self));
 }
 
+static void
+on_uids_make_primary_cb (GObject *source, GAsyncResult *res, gpointer user_data)
+{
+    SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+    SeahorseGpgmeUid *uid = SEAHORSE_GPGME_UID (source);
+    g_autoptr(GError) error = NULL;
+
+    if (!seahorse_gpgme_key_op_make_primary_finish (uid, res, &error)) {
+        GtkWindow *window;
+        window = gtk_window_get_transient_for (GTK_WINDOW (self));
+        seahorse_util_show_error (GTK_WIDGET (window),
+                                  _("Couldn’t change primary user ID"),
+                                  error->message);
+    }
+}
+
 static void
 on_uids_make_primary (GSimpleAction *action, GVariant *param, gpointer user_data)
 {
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
     SeahorsePgpUid *uid;
-    gpgme_error_t err;
 
     uid = names_get_selected_uid (self);
-    if (uid) {
-        g_return_if_fail (SEAHORSE_GPGME_IS_UID (uid));
-        err = seahorse_gpgme_key_op_primary_uid (SEAHORSE_GPGME_UID (uid));
-        if (!GPG_IS_OK (err))
-            seahorse_gpgme_handle_error (err, _("Couldn’t change primary user ID"));
-    }
+    if (!uid)
+        return;
+
+    g_return_if_fail (SEAHORSE_GPGME_IS_UID (uid));
+    seahorse_gpgme_key_op_make_primary_async (SEAHORSE_GPGME_UID (uid),
+                                              NULL,
+                                              on_uids_make_primary_cb, self);
 }
 
 static void
@@ -365,7 +381,7 @@ names_populate (SeahorsePgpKeyProperties *self, GtkTreeStore *store, SeahorsePgp
         g_autoptr(GCancellable) cancellable = NULL;
 
         uid = SEAHORSE_PGP_UID (u->data);
-        icon = g_themed_icon_new (SEAHORSE_ICON_PERSON);
+        icon = g_themed_icon_new ("avatar-default-symbolic");
         gtk_tree_store_append (store, &uiditer, NULL);
         gtk_tree_store_set (store, &uiditer,
                             UIDSIG_OBJECT, uid,
@@ -430,7 +446,6 @@ do_names (SeahorsePgpKeyProperties *self)
 
         /* Icon column */
         renderer = gtk_cell_renderer_pixbuf_new ();
-        g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
         gtk_tree_view_insert_column_with_attributes (self->names_tree,
                                                      -1, "", renderer,
                                                      "gicon", UIDSIG_ICON, NULL);
@@ -828,7 +843,6 @@ do_owner (SeahorsePgpKeyProperties *self)
 
             /* Make the columns for the view */
             renderer = gtk_cell_renderer_pixbuf_new ();
-            g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
             gtk_tree_view_insert_column_with_attributes (self->owner_userid_tree,
                                                          -1, "", renderer,
                                                          "gicon", UID_ICON, NULL);
@@ -843,7 +857,7 @@ do_owner (SeahorsePgpKeyProperties *self)
             g_autoptr(GIcon) icon = NULL;
 
             markup = seahorse_object_get_markup (l->data);
-            icon = g_themed_icon_new (SEAHORSE_ICON_PERSON);
+            icon = g_themed_icon_new ("avatar-default-symbolic");
             gtk_list_store_append (store, &iter);
             gtk_list_store_set (store, &iter,
                                 UID_OBJECT, l->data,
